pico-8 cartridge // http://www.pico-8.com
version 41
__lua__

-- vacation (18+)
-- kistaro windrider

--------------------------------
-- copyright (C) 2024 kistaro windrider
--
-- this program is free software; you can redistribute it and/or modify
-- it under the terms of the gnu general public license as published by
-- the free software foundation; either version 2 of the license, or
-- (at your option) any later version.
--
-- this program is distributed in the hope that it will be useful,
-- but without any warranty; without even the implied warranty of
-- merchantability or fitness for a particular purpose.  see the
-- gnu general public license for more details.
--------------------------------

-- addtional credits
-- dogica font by roberto mocci
-- https://www.dafont.com/es/dogica.font
--
-- converted by josれた aular
-- https://jaular.itch.io/pico-8-dogica-font

-- tab 0: library
-- tab 1: p8 entry points
-- tabs 2...F: actual code

function usplit(str)
 return unpack(split(str))
end
function csv(s)
 local ret = split(s, "\n")
 for i, v in ipairs(ret) do
  ret[i] = type(v) == "string" and split(v) or { v }
 end
 return ret
end

-- generate standard "overlay"
-- constructor for type tt.
-- if more is defined, generated
-- new calls more(ret) after
-- ret is definitely not nil
-- before calling setmetatable.
-- use to initialize mutables.
--
-- if there was a previous new,
-- it is invoked on the new
-- object *after* more, because
-- this works better with the
-- `more` impls i use.
function mknew(tt, more)
 local mt, oldnew={__index=tt},tt.new
 tt.new=function(ret)
  if (not ret) ret = {}
  if (more) more(ret)
  if (oldnew) oldnew(ret)
  setmetatable(ret, mt)
  return ret
 end
end

event_list = {is_event_list=true}
mknew(event_list, function(x)
  x.next=nil
  x.tail=x
 end)

function event_list:push_back(x)
 self.tail.next = x
 self.tail = x
end

function event_list:strip(f)
 local p, n = self, self.next
 while n do
  if f(n) then
   p.next = n.next
  else
   p = n
  end
  n = n.next
 end
 self.tail = p
 return p
end


function event_list:update()
 local p, n = self, self.next
 while n do
  if n:update() then
   p.next = n.next
  else
   p = n
  end
  n = n.next
 end
 self.tail = p
 return p
end

function event_list:draw()
 local n = self.next
 while n do
  n:draw()
  n = n.next
 end
end

-- if t[mname] is a thing,
-- invoke it as a method. else,
-- try each object in t
function outer_or_each_opt(t, mname)
 local fun = t[mname]
 if fun then
  fun(t)
  return
 end
 foreach(t, function(o)
  local f = o[mname]
  if(f) f(o)
 end)
end

function nop() end

-- puke emits a verbose string
-- describing item, indented to
-- the specified depth (0 by
-- default). used for table
-- debugging. table-type keys
-- are not legible here
function puke(item, indent, seen, hidekey)
 if (type(item) ~= "table") return tostr(item)
 
 seen = seen or {}
 if (seen[item]) return "<<...>>"
 seen[item] = true
 
 indent = indent or 0
 local pfx = "\n"
 for _=1,indent do
  pfx ..= " "
 end
 local xpfx = pfx.." "

 if item.is_event_list then
  local ret,n = "event_list <",0
  item:strip(function(x)
   n += 1
   ret ..= xpfx..tostr(n)..": "..puke(x, indent+2, seen, "next")
  end)
  return ret..pfx..">"
 end

 local ret = "{"
 for k, v in pairs(item) do
  if (k ~= hidekey) ret ..= xpfx..tostr(k)..": "..puke(v, indent+2, seen)
 end
 return ret..pfx.."}"
end

-- convenience for debugging
function puketh(item, ...)
 printh(puke(item), ...)
end

function pukeboard(item)
 puketh(item, "@clip")
end

-------------------------------
-- view
-------------------------------
-- composits drawable items.
-- add items to .views to
-- composit them. x and y are
-- relative reverse camera
-- offsets. drawable items will
-- observe appropriate incoming
-- camera and clip state.
-- clipping respects existing
-- clipping so stacked views
-- intersect.
-------------------------------
view = {
 x=0,
 y=0,
 w=128,
 h=128,
}
mknew(view, function(x)
 if (not x.views) x.views = {}
end)

function view.of(subviews)
 return view.new{views=subviews}
end

function view:update()
 outer_or_each_opt(self.views, "update")
end

function view:draw()
 local oldcam, oldclip = $0x5f28, $0x5f20
 poke2(0x5f28, %0x5f28-self.x)
 poke2(0x5f2a, %0x5f2a-self.y)
 clip(-%0x5f28, -%0x5f2a, self.w, self.h, true)
 outer_or_each_opt(self.views, "draw")
 poke4(0x5f20, oldclip)
 poke4(0x5f28, oldcam)
end

-- draws opaque rectangles.
-- default bg is equivalent to
-- clip-aware cls.
-- restores prior fill pattern.
bg = {
 x=0,y=0,w=128,h=128,fp=0,c=0
}
mknew(bg)

function bg:draw()
 local oldfp=fillp(self.fp)
 rectfill(self.x,self.y,self.x+self.w,self.y+self.h,self.c)
 fillp(oldfp)
end

-->8
-- setup and p8 entry points

function _init()
 -- disable btnp repeat
 -- TODO: set back to 30 frames
 -- outside of game mode
 poke(0x5f5c, 255)

 -- complex fill API mode
 poke(0x5f34, 1)

 mainview = ao_splash.new()
end

function _update60()
 mainview:update()
end

function _draw()
 mainview:draw()
end

function font_dogica()
 memcpy(0x5600, 0x2000, 0x800)
 poke(0x5f58, 0x81)
end

function font_compact()
 memcpy(0x5600, 0x2800, 0x800)
 poke(0x5f58, 0x81)
end

function font_default()
 poke(0x5f58, 0x80)
end

-->8
-- text rendering

-- text colors for zonk mode:
--  8 -- standard
--  9 -- delayed fade
-- 10 -- currently fading in
txtbox = {
 x=0,
 y=0,
 text="???",
 col=8,
 mode=0x81,
}
mknew(txtbox)

function txtbox:update() end

function txtbox:draw()
 poke(0x5f58, self.mode)
 print(self.text, self.x, self.y, self.col)
end

function txtbox:xmax()
 return print(self.text, self.x, -9999)
end

spring = {
 from = 128,
 to = 0,
 frames=120,
 f = 0,
}
mknew(spring)

function spring:update()
 local v = self.v
 self.v:update()
 if self.f >= self.frames then
  v.y=self.to
  return true
 end
 local t, range = self.f/self.frames, self.to - self.from
 v.y = self.to-range*(2^(-10*t)*cos(2*t))
 self.f += 1
end

function spring:draw()
 self.v:draw()
end

scoot = {
 from=0,
 to=-128,
 frames=60,
 f=0,
}
mknew(scoot)

function scoot:update()
 local v = self.v
 self.v:update()
 if self.f >= self.frames then
  v.y=self.to
  return true
 end
 self.f += 1
 if self.f < 0 then
  v.y=self.from
  return
 end
 local t, range = self.f/self.frames, self.to - self.from
 v.y = self.from + range * t * t * t
end

function scoot:draw()
 self.v:draw()
end

scootbox = {}
mknew(scootbox, function(x)
 x.v = view.new()
 x.s = scoot.new{
  from=x.from or scoot.from,
  to=x.to or scoot.to,
  frames=x.frames or scoot.frames,
  v=x.v
 }
end)

function scootbox:update()
 if self.go then
  self.s:update()
 else
  self.v:update()
 end
end

function scootbox:push(drawable)
 add(self.v.views, drawable)
end

function scootbox:done()
 return self.s.f >= self.s.frames
end

function scootbox:draw()
 return self.v:draw()
end

-->8
-- zonk renderer

fadetable = split"0,1.5,1025.5,1029.5,1285.5,1413.5,9605.5,9637.5,-23130.5,-23066.5,-18970.5,-18954.5,-2570.5,-2568.5,-520.5,-8.5,-0.5"

ditherer = {
 i = 0,
 di = 0.25,
 c=0,
 pattern=fadetable,
}
mknew(ditherer, function(x)
 if (x.di and x.di < 0 and not x.i) x.i = (x.pattern and #x.pattern or #fadetable) + 0.99
end)

function ditherer:update()
 if (self.i > 0 and self.di < 0) self.i += self.di
 if (self.i < #self.pattern + 1 and self.di > 0) self.i += self.di
 return self.i < 0 or self.i >= #self.pattern + 1
end

function ditherer:draw()
 local idx = min(flr(self.i), #self.pattern)
 if (idx < 1) idx = 1
 fillp(self.pattern[#self.pattern+1-idx])
 rectfill(0,0,128,128,self.c)
end

fuzzy = {
 p = 0xffff,
 n = 0,
 interval = 3,
 tries = 2,
}
mknew(fuzzy, function(x)
 local p = (x.p or fuzzy.p) & 0xffff
 x.mass = 0
 while p ~= 0 do
  x.mass += p & 1
  p = (p >>> 1) & 0xffff
 end
end)

function fuzzy:update()
 self.n += 1
 if (self.n < self.interval) return
 self.n = 0
 for i=1,self.tries do
  local b = 1 << rnd(16)
  if b & self.p == 0 then
   if i == self.tries or not self.weight or self.mass <= self.weight then
    self.mass += 1
    self.p |= b
    return
   end
  else
   if i == self.tries or not self.weight or self.mass >= self.weight then
    self.mass -= 1
    self.p &= ~b
    return
   end
  end
 end
end

function fuzzy:set_fillp()
 fillp(self.p + 0x0.8)
end

fuzzy_stripey = {
 y = 0,
 dy = -0.25,
 thicc = 3,
 weight = 12,
 spacing = 7,
 gap = 32,
 colors = {5, 2, 1},
}
mknew(fuzzy_stripey, function(f)
 f.fuzz = fuzzy.new{
  weight = f.weight or fuzzy_stripey.weight,
  interval = f.interval or fuzzy.interval,
  tries = f.tries or fuzzy.tries,
 }
end)

function fuzzy_stripey:update()
 self.y += self.dy
 if (self.y <= -self.gap) self.y += self.gap
 if (self.y >= self.gap) self.y -= self.gap
 self.fuzz:update()
end

function fuzzy_stripey:draw()
 self.fuzz:set_fillp()
 for y=self.y,128,self.gap do
  for i,c in ipairs(self.colors) do
   local y0 = y + (i-1) * self.spacing
   rectfill(0, y0, 128, y0 + self.thicc, c)
  end
 end
end


--@musurca & @felice
function cminskycirc(r,c)
 local j,k,rat=r,0,1/r
 poke(0x5f25,c) --set color
 for i=1,r*0.785 do
  k-=rat*j
  j+=rat*k
  pset(63.5+j,63.5+k)
  pset(63.5+j,63.5-k)
  pset(63.5-j,63.5+k)
  pset(63.5-j,63.5-k)
  pset(63.5+k,63.5+j)
  pset(63.5+k,63.5-j)
  pset(63.5-k,63.5+j)
  pset(63.5-k,63.5-j)
 end
 pset(63.5,63.5-r)
 pset(63.5,63.5+r)
 pset(63.5-r,63.5)
 pset(63.5+r,63.5)
end

breather = {
 colors = {1,2,4,2,1},
 sep = 5,
 speed=240,
 f=0,
}
mknew(breather)

function breather:update()
 if (self.freeze) return
 local f = self.f + 1
 if (not self.on) f = 0
 if (f >= self.speed) f = -self.speed
 if f == 0 and self.nextspeed then
  self.speed = self.nextspeed
  self.nextspeed = nil
 end
 self.f = f
end

function easeinout(t)
 if(t<.5) then
     return t*t*t*4
 else
     t-=1
     return 1-t*t*t*-4
 end
end

function breather:draw()
 fillp(0)
 local cols, f, spd, sep = self.colors, self.f, self.speed, self.sep
 local stall = sep * (#cols - 1)
 local cap = spd-stall
 if (f >= 0) f += stall
 for i,c in ipairs(cols) do
  local ef = f - (i-1)*sep
  ef = abs(ef) - stall
  if ef <= cap and ef > 0 then
   cminskycirc(easeinout(ef/cap)<<6,c)
  end
 end
end

function breather:starting_reverse()
 return self.f + self.speed < self.sep * #self.colors
end

-->8
-- awakener


-->8
-- consent screens

ao_splash = {
 fwait = 180,
}
mknew(ao_splash, function(self)
 self.c = breather.new{
  colors={7,15,14,8,2},
  sep=3,
  f=15,
  on=true,
 }
 font_dogica()
end)

function ao_splash:update()
 if self.c.f < self.c.speed/2.5 then
  self.c:update()
  return
 end
 self.fwait -= 1
 if (self.fwait < ao_splash.fwait-30 and (btnp() & 0xf > 0) and self.fwait > 0) self.fwait = 0
 if self.fwait == 0 then
  self.d = ditherer.new{di=1}
 end
 if (self.d) self.d:update()
 if self.fwait <= -32 then
  -- TODO: consent screen
  mainview=newtitle()
  mainview:update()
 end
end

function ao_splash:draw()
 cls()
 self.c:draw()
 if self.fwait < ao_splash.fwait then
  print("18+", 55, 60, 7)
  print("aDULTS ONLY", 35, 90, 15)
 end
 if (self.d) self.d:draw()
end
-->8
-- title screen

-- currently just loading
-- whatever view I want to debug
function newtitle()
 local ret = title_screen.new()
 ret:activate()
 return ret
end

title_screen = {}
mknew(title_screen, function(t)
 t.d = ditherer.new{
  di = -1
 }
end)

function title_screen:activate()
 font_dogica()
end

function title_screen:draw()
 pal()
 clear_alt_pal_bits()
 cls(12)
 print("title screen", 30, 57, 0)
 print("press right arrow", 15, 66, 0)
 self.d:draw()
end

function title_screen:update()
 if (btnp(1)) self.d.di = 1
 if(self.d:update() and self.d.di > 0) start_game()
end
-->8
-- dolphin sprite renderer

phinstate_nrm = {
 --s={4, 36, 4, 9},
 s={4},
 ws=3,
 hs=2,
 idle=true,
 xo=-12,
 yo=-8,
}
phinstate_jump_full = {
 s={64},
 ws=2,
 hs=3,
 xo=-4,
 yo=-8, 
}
phinstate_jump_wane = {
 s={69},
 ws=3,
 hs=3,
 xo=-12,
 yo=-8,
}
phinstate_crest = {
 s={72},
 ws=3,
 hs=2,
 xo=-12,
 yo=-8,
}
phinstate_fall_wax = {
 s={128},
 ws=3,
 hs=3,
 xo=-12,
 yo=-16,
}
phinstate_fall_full = {
 s={77},
 ws=2,
 hs=3,
 xo=-4,
 yo=-16,
}
phinstate_dive_full = phinstate_fall_full
phinstate_dive_wane = {
 s={128},
 ws=3,
 hs=3,
 xo=-12,
 yo=-16,
}
phinstate_return = {
 s={104},
 ws=3,
 hs=2,
 xo=-12,
 yo=-8,
}
phinstate_rise_wax = phinstate_jump_wane
phinstate_rise_full = phinstate_jump_full

phinstate_error = {
 s={0},
 ws=1,
 hs=2,
}

-- coordinates are the notional
-- center point of the dolphin.
-- many states are off-center.
toyphin = {
 x=-12,
 y=64,
 dy=0,
 state=phinstate_nrm
}
mknew(toyphin)

function toyphin:update()
 local x, y, dy, splash = self.x, self.y, self.dy, self.splasher
 -- entry mode?
 if not self.entered then
  x += 1
  self.entered = x >= 16
 elseif self.exiting then
  if x + self.state.xo > 128 then
   self.exited = true
  else
   x += 1
  end
 end

 -- button handling
 if self.entered and not self.exiting then
  if y >= 61 and y <= 67 then
   if (btn(2)) and dy < 1 then
    splash:jump_splash(x)
    dy=-3.8
   elseif (btn(3)) and dy > -1 then
    splash:dive_splash(x)
    dy=3.8
   end
  else
   dy += (btn(3) and 0.125 or 0) - (btn(2) and 0.125 or 0)
  end
 end

 if (y > 64) dy -= 0.3
 if (y < 64) dy += 0.3

 local new_y = y + dy
 if new_y  <= 64 and y > 64 then
  -- surfacing
  splash:surfacing_splash(x, -dy, btn(2) and (dy > -3.8))
  if btn(2) then
   -- maybe boost
   if dy > -3.8 then
    new_y = 64 + ((dy + y - 64)/dy * -3.8) 
    dy = -3.8
   else
    dy = (dy - 7.6) / 3
   end
  else
   -- brake
   if dy > -0.75 then
    --stabilize
    new_y = 64
    dy = 0
   else
    dy /= 2
   end
  end
 elseif new_y >= 64 and y < 64 then
  -- landing
  splash:landing_splash(x, dy, btn(3) and (dy < 3.8))
  if btn(3) then
   -- maybe boost
   if dy < 3.8 then
    new_y = 64 - ((dy - y + 64)/dy * 3.8)
    dy = 3.8
   else
    dy = (7.6 + dy) / 3
   end
  else
   --brake
   if dy < 0.75 then
    --stabilize
    new_y = 64
    dy = 0
   else
    dy /= 2
   end
  end
 end
 y=new_y

 local wet, st = y > 64, phinstate_error
 if dy < -2.15 then
  st = wet and phinstate_rise_full or phinstate_jump_full
 elseif dy <= -1 and (y < 60 or y > 68) then
  st = wet and phinstate_rise_wax or phinstate_jump_wane
 elseif dy <= -1 then
  st = phinstate_nrm
 elseif dy < 1 then
  -- handle idle special case later
  st = wet and phinstate_return or phinstate_crest
 elseif dy <= 2.15 and (y < 60 or y < 68) then
  st = wet and phinstate_dive_wane or phinstate_fall_wax
 elseif dy <= 2.15 then
  st = phinstate_nrm
 else
  st = wet and phinstate_dive_full or phinstate_fall_full
 end

 if (y == 64 and dy == 0) st = phinstate_nrm
 -- test mode
 --if (btn(5)) self.exiting = true
 self.x, self.y, self.dy, self.state = x, y, dy, st
end

-- hitbox for current state
function toyphin:box()
 local st = self.state
 return {self.x + st.xo, self.y + st.yo, st.ws * 8, st.hs * 8}
end

function toyphin:draw()
 local st, y = self.state, self.y
 if (st.idle) y += wave()
 spr(st.s[1+(((t()<<1)&0x0.FFFF*#st.s)&0x7FFF)], self.x + st.xo, y + st.yo, self.state.ws, self.state.hs)
end

-->8 word target

wordtarget = {
 x = 129,
 y = 60,
 str = "GOOD TOY!",
 on_hit = nop,
}
mknew(wordtarget, function(x)
 poke(0x5f58, 0x81)
 x.w = print(x.str or wordtarget.str, 0, -9999)-1
end)

function collides(b1, b2)
 if (b1[1] > b2[1] + b2[3]) return false
 if (b1[1] + b1[3] < b2[1]) return false
 if (b1[2] > b2[2] + b2[4]) return false
 return not (b1[2] + b1[4] < b2[2])
end

function wordtarget:update()
 if collides({self.x, self.y, self.w, 6}, self.phin:box()) then
  self:on_hit()
  return true
 end
 self.x -= 1
 return self.x < -self.w
end

function wordtarget:draw()
 poke(0x5f58, 0x81)
 -- debug: show hitbox
 --rect(self.x-1, self.y-1, self.x+self.w+1, self.y + 8, 0x10F1.5a5a)
 print(self.str, self.x+1, self.y+1, 0x100b)
 print(self.str, self.x, self.y, 0x100a)
end

-->8
-- arcade mode

-- palette use:
-- 0: shallow sea blue (1)
-- 1: black (for sprites)
-- 2: dolphin shading
-- 3: azure water, maybe score display? (140)
-- 4, 5: unassigned, layer-specific
-- 6: dolphin specular highlights
-- 7: dolphin white paint
-- 8, 9: unassigned, layer specific
-- 10: word primary (yellow 10?)
-- 11: word shadow (wood 132?)
-- 12: dolphin eye
-- 13: common sky color
-- 14: dolphin primary color
-- 15: highlight white (all layers)
--
-- dolphin colors are different
-- between zones; correlated.
-- wave, text, and black colors
-- are the same between zones.
-- other colors are for
-- elements that only ever
-- appear in one zone.
--
-- TODO: consider changing sky
-- colors in different stages;
-- document what colors those
-- are (nrm_pal) if so.
game_nrm_pal = {
 [0] = 1, 0, 2, 140, 4, 5, 7, 7, 8, 9, 10, 132, 12, 12, 14, 7
}

-- undersea palette local decisions:
-- 4: deeper sea blue (129)
game_uw_pal = {
 [0]=1, 0, 130, 140, 129, 5, 141, 13, 8, 9, 10, 132, 131, 12, 141, 7
}

function setup_arcade_pal()
 -- per-line color mode
 poke(0x5f5f, 0x10)
 -- rows 72 and lower: sea
 memset(0x5f79,0xff,7)
 pal()
 pal(game_nrm_pal, 1)
 pal(game_uw_pal, 2)
end

-- global wave amplitude clock
-- wave per 2 seconds
-- optional toff: offset. at
-- toff==0 draw directly under
-- the dolphin
function wave(toff)
 toff = toff or 0
 return 2.5 * sin((t()+toff)>>1)
end

function clear_alt_pal_bits()
 memset(0x5f70,0x0,16)
end

sea = {}
mknew(sea)

function sea:draw()
 local w = wave()
 rectfill(0, 66+w, 128, 77+w, 0x1000)
 poke2(0x5f78, 0xffe0.00ff <<> w)
 rectfill(0, 78+w, 128, 89+w, 0x1040.a842)
 rectfill(0, 90+w, 128, 97+(w>>1), 0x1004.e169)
 rectfill(0, 98+(w>>1), 128, 104+(w>>2), 0x1004.a842)
 rectfill(0, 104+(w>>2), 128, 110+(w>>2), 0x1004)
 rectfill(0, 111+(w>>2), 128, 118+(w>>3), 0x1041.e169)
 rectfill(0, 119+(w>>3), 128, 124+(w>>3), 0x1041.a842)
 rectfill(0, 125+(w>>3), 128, 128, 0x1001)
end

arcade_level = {
 score=0,
 max_score=999,
 wordwait = 90,
}
mknew(arcade_level, function(x)
 x.phin = toyphin.new{splasher=x}
 -- TODO: decent looking sky and sea
 x.sky = bg.new{c=13}
 x.sea = sea.new()
 x.bg = event_list.new()
 x.fg = event_list.new()
 x.words = event_list.new()
 -- TODO: score renderer
 x.t0 = t()
 x.wordremain = x.max_score or arcade_level.max_score
 x.wordtimer = x.wordwait or arcade_level.wordwait

 x.v = view.of{
  x.sky,
  x.sea,
  x.waves,
  {draw=function()
   poke(0x5f58, 0)
   local s = tostr(x.score)
   print(s,1,2,3)
   print(s,2,1,3)
   print(s,0,1,3)
   print(s,1,0,3)
   print(s,1,1,15)
  end},
  x.bg,
  x.phin,
  x.fg,
  x.words,
 }
 x.d = ditherer.new{
  c=1,
  di = 0.34,
 }

 -- TODO: fade in level music

 -- Switch to small font
 -- (Dogica is too large to ever miss!)
 font_compact()
end)

function arcade_level:update()
 if self.phin.entered then
  if self.wordtimer <= 0 and self.wordremain > 0 then
   self:spawn_word()
   self.wordtimer = self.wordwait
   self.wordremain -= 1
  end
  self.wordtimer -= 1
 end
 if self.wordremain <= 0 and self.words.next == nil then
  self.phin.exiting = true
 end
 if self.phin.x > 90 then
  if (self.d:update()) seq:next()
 end
 self.v:update()
 -- TODO: timers, word loop,
 -- level state tracking and
 -- progression, etc.
end

function arcade_level:spawn_word()
 -- TODO: basically everything.
 --  word lists
 --  pattern generator 
 self.words:push_back(wordtarget.new{
  y=32+rnd(64), -- real game uses pattern generator!
  phin=self.phin,
  on_hit = function(word)
   self:word_hit(word)
  end,
 })
end

function arcade_level:word_hit(word)
 self.score += 1
 -- TODO: sfx
 -- TODO: sparkle
end

function arcade_level:draw()
 setup_arcade_pal()
 self.v:draw()
 self.d:draw()
end

function arcade_level:draw_splash(x, force)
 if (force < 0.5) return
 local n = (force + rnd(force)) & 0x7FF
 for i=0,n do
  local d = droplet.new{x=x, force=force, y=72+wave(), f=i/n-0.5}
  if rnd() < 0.5 then
   self.bg:push_back(d)
  else
   self.fg:push_back(d)
  end
 end
end

function arcade_level:dive_splash(x)
 -- TODO: sfx, vfx for dive input
 self:draw_splash(x, 3.8)
end

function arcade_level:jump_splash(x)
 -- TODO: sfx, vfx for jump input
 self:draw_splash(x, 3.8)
end

function arcade_level:surfacing_splash(x, force, harder)
 -- TODO: sfx, vfx for surfacing from a dive
 self:draw_splash(x, force)
end

function arcade_level:landing_splash(x, force, harder)
 -- TODO: sfx, vfx for landing from a jump
 self:draw_splash(x, force)
end

splashcols = {0x1003, 0x103d.a5a5}
droplet = {}
mknew(droplet, function(d)
 d.dx = (d.f * d.force >> 2) - 0.75
 d.x += 16 * d.f
 d.dy = -rnd(d.force*0.66)
 d.r = 1 + rnd(0.75 + (d.force >> 4))
 d.c = rnd(splashcols)
end)

function droplet:update()
 self.x += self.dx
 self.y += self.dy
 self.dy += 0.3
 return self.y >72 + wave()
end

function droplet:draw()
 circfill(self.x, self.y, self.r, self.c)
 local r2 = self.r >> 1
 pset(self.x+r2, self.y-r2, 0x100F)
end

-->8
-- game sequencer

sequencer = {
 idx = 0,
 score = 0,
 max_score = 0,
}
mknew(sequencer)

function sequencer:next()
 if (mainview.score) self.score += mainview.score
 if (mainview.max_score) self.max_score += mainview.max_score
 self.idx += 1
 local rec = self[self.idx]
 if rec == nil then
  mainview = newtitle()
  return
 end
 if rec.params then
  mainview = rec.f(unpack(rec.params))
 else
  mainview = rec.f()
 end
 mainview:update()
end

function start_game()
 seq = sequencer.new{
--  {
--   f = arcade_level.new,
--   params = {{
--    max_score=2,
--   }}
--  },
  {
   f = function()
    pal()
    clear_alt_pal_bits()
    return view.of{
     bg.new(),
     fuzzy_stripey.new{interval=7, tries=5},
     breather.new{on=true},
    }
   end,
  },
 }
 seq:next()
end

__gfx__
00888800777777777777777777777777000000000000000000000000777777777777777700000000000000000000000000000000000000000000000000000000
0888e780700000000000000000000007000000000000000000000000700000000000000700000000000000000000000000000000000000000000000000000000
88888878700000000000000000000007000000000000000000000000700002222220000700000000000000000000000000000000000000000000000000000000
88a8a8e8700000000000000000000007000000000000000000000000700002eeee2000070000000000ee00000000000000000000000000000000000000000000
888a888870000000000000000000000700000000022260000000000070000222e22000070000000000e7e00000000000000000000eee70000000000000000000
88a8a888700000000000000000000007000000000022260000000000700002eeee20000700000000002e7e00000000000000000000eee7000000000000000000
08888880700000000000000000000007000000000002222600000000700002222220000700000000000ee7ee0000000000000000000eeee70000000000000000
008888007000000000000000000000070220000000266222662000007000022e2200000700000000e7eee7e77ee000000ee0000000ee7eee77e0000000000000
00000000700000000000000000000007226200002662222222222000700002e2e22000070e00000eee7eeeeeeeeee000ee7e0000e77eeeeeeeeee00000000000
00000000702222022222222222222207022626622222222227772620700002eeee200007e77e0e7eeeee77eee777e7e00e77eeeeeeeeeeeee777e7e000000000
00000000702ee222e22e22ee22e2e2070e2622222222222227c122627000022222200007eee7eee7e222eeeee7c1ee7e02e7ee77eeeeeeeee7c1ee7e00000000
00000000702e2e2e2e2e22e2e2e2e207222222eee222222222eee262700002222e20000702eeeee2222222eeee222e7eeeeeee222eeeeeeeee222e7e00000000
00000000702e2e2e2e2e22ee22eee207222eeeeeeeeee2222eeeeee0700002eeee2000072e7ee20000022eeee2222220eee2222222222eeee222222000000000
00000000702eee22e22ee2e222e2e2072eee0000eeee22262eeee0007000022222200007eeee20000000ee7e22222000e22200002222ee7e2222200000000000
00000000702222222222222202222207ee00000000022262000000007000022ee2200007ee220000000eeee70000000022000000000eeee70000000000000000
00000000700000000000000000000007000000000022220000000000700002e22e200007020000000eee220000000000000000000eee22000000000000000000
000000007000000000000000000000070000000000000000000000007000022ee220000700000000000000000000000000000000000000000000000000000000
00000000700000000000000000000007000000000000000000000000700000222220000700000000000000000000000000000000000000000000000000000000
000000007000000000000000000000070000000000000000000000007000022eee20000700000000000000000000000000000000000000000000000000000000
000000007000000000000000000000070000000000ee000000000000700002e22e20000700000000000000000000000000000000000000000000000000000000
000000007000000000000000000000070000000000e7e00000000000700002eeee200007000000000222e0000000000000000000022270000000000000000000
0000000070000000000000000000000700e00000002e7e000000000070000222222000070000000000222e000000000000000000002227000000000000000000
000000007000000000000000000000070eee0000000ee7ee000000007000000000000007000000000002222e0000000000000000000222270000000000000000
000000007777777777777777777777770e7e0000002ee7e77ee000007777777777777777022000000022e222ee20000002200000002272227720000000000000
0000000000000000000000000000000002e7ee0002ee7eeeeeeee000000000000000000022e200002ee222222222200022720000277222222222200000000000
00000000000000000000000000000000eeeee7eeee777eeee777e7e0000000000000000002ee22222222222227772e2002772222222222222777272000000000
00000000000000000000000000000000eee22e77eeeeeeeee7c1ee7e0000000000000000022e22ee2222222227c122e20e2722772222222227c1227200000000
00000000000000000000000000000000220022222eeeeeeeee222e7e00000000000000002222227772222222227772e2222222eee222222222eee27200000000
000000000000000000000000000000000000002222222eeee22222200000000000000000222777777777722227777770222eeeeeeeeee2222eeeeee000000000
00000000000000000000000000000000000000002222ee7e22222000000000000000000027770000777722e2777770002eee0000eeee2272eeeee00000000000
0000000000000000000000000000000000000000000eeee7000000000000000000000000770000000002222e00000000ee000000000222270000000000000000
00000000000000000000000000000000000000000eee2200000000000000000000000000000000000222770000000000000000000222ee000000000000000000
00000000000066000000000000000000000002200000000000000000000002200000000000000000000000000000000000000000000000000000000000000000
0000000000022260000000000000000000222662000000000000000000222662000000000000000000000000000070220000000000220e220000000000000000
00000000002222e000000000000000006227222e00000000000000002227222e0000000000000000000000000222026200000000022262220000000000000000
0000000002712ee00000000000060026227c1eee0000000000006622227c1eee0000000000220000000000000e22e262000000000e2226220000000000000000
00000000627ceee00000000000222222227ceee000000000006622266272eee000000000002620000000000000ee26220000000000ee22260000000000000000
000000022277eee000000000022226222222eee000000000022222622222eee0000000000022620000000000000ee22600000000000ee2220000000000000000
000000222222ee0000000000000062222222ee0000000000000022222222ee000000000000022622000000000000e226000000000000e2220000000000000000
000066226622ee000000000000006222222220000000000000002222222220000000000026222626622000000000eee2200002000000ee222000000000000000
0006222622226e0000000000000622222226000000000000000222222226000002000002622222222222200000000ee22200020000000ee26200000000000000
00022222222226000000000000022222e22600000000000000022222e226000026620222222222222777262000000ee22266022000000ee22620002000000000
0022002222222200000000000062222ee000000000000000002222eee22e0000222622222eee222227c1226200000ee22226226000000ee22222022000000000
0000002226ee2600000000000662eeee000000000000000002222eee022e00000e22222eeeeeee2222eee26200000ee22222226000020ee22226262000000000
0000002226ee2260000000222222eee000000000000000662222ee0002e00000e2622e00000ee2222eeeeee2000022ee22222200000266ee2222622000000000
000000222ee0022000000226622ee0000000000000000222622ee000000000002222e00000002262eeeeee000000222222222600000222226222260000000000
00000022eee0022000000222222e00000000000000000222222e00000000000022ee000000022226000000000000222222222600000022222622220000000000
0000022eee0000200000000e22e00000000000000000000e22e00000000000000e00000002222200000000000000006622222260000000222222220000000000
0000022ee00000000000000222e00000000000000000000226e000000000000000000000000000000000000000000002222772200000000ee227720000000000
0000022e00000000000000002ee0000000000000000000002ee000000000000000000000000000000000000000000000eeec720000000000eeec720000000000
0006622e00000000000000000ee0000000000000000000000ee000000000000000000000000000000000000000000000eeee1200000000000ee1720000000000
0022226e00000000000000000000000000000000000000000000000000000000000000000022000000000000000000000eee2600000000000ee2220000000000
02222226000000000000000000000000000000000000000000000000000000000000000000262000000000000000000000ee26000000000000ee220000000000
022e022e0000000000000000000000000000000000000000000000000000000000200000002262000000000000000000000e620000000000000e200000000000
0200022e000000000000000000000000000000000000000000000000000000000222000000022622000000000000000000002200000000000000000000000000
00000020000000000000000000000000000000000000000000000000000000000262000000222626622000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000e26220002226222222220000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000002222262222666222277726200000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000222ee2662222222227c122620000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000ee00eeeee222222222eee2620000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000eeeeeee2222eeeeee00000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000eeee2262eeeee0000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000022226000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000222ee00000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000026000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000022600000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000002e22600000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000022222200000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000ee6622220000020000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000eeee22226000026000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000ee622620026000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000ee22222222600000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000ee2222222200000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000ee222266200000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000ee222622200000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000ee22222660000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000222662222220000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000e22222227722000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000eee22222c72000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000002eee122000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000eeee26200000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000eee22600000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000ee2000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
__label__
cssscccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
s777sccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
s7s7sccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
s7s7sccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
s7s7sccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
s777sccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cssscccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
2ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
222ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
77272ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c0227211111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111
eee27211111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111
eeeee111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111
ttt11111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111
11111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111
11111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111
11111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111
11111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111
11111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111
11111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111
11111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111
11111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111
h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1
h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111
1h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h11
11h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h1
h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1
h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111
1h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h11
11h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h1
h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1
h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111
1h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h11
11h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h1
111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h
hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1
h11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11h
1hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh1
111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h
hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1
h11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11h
1hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh11hh1
111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h111h
1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh
h1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hh
hh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1h
1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h1h
1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh
h1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hhh1hh
hhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
hhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
hhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
hhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
hhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
hhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
hhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
0hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh0
h00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00h
hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0
000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h
0hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh0
h00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00hh00h
hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0hhh0
000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h
0h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h00
00h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h0
h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0h0
h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000
0h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h00
00h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h000h0
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000

__map__
0608090000010000000000000000000045102051550075740000000000541606020000006006260000070710705750100500010070072700000000200070740100006066600060600060000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000101010101000100000a0a050000000000123f12123f1200000e15050e14150e2215150a285454220609090629112e000002020100000000020101010101020001020202020201000004150a150400000004041f040400000000000000020201000000000f00000000000000000001000808040402020101
0e11151515110e000407040404041f000e11100804021f000f10100e10100f00080c0a091f0808001f010f1010110e000e11010f11110e001f111008040202000e11110e11110e000e11111e1008060000000100000100000000000200020201000402010204000000003f003f00000000010204020100000e11100c02000400
1e212d291d413e00000e101e11111e0001010f1111110f00000e110101011e0010101e1111111e00000e111f01011e001c02020f02020200001e1111111e100e01010d131111110002000302020207000007020202020201001109050709110000010101010106000036494949494900000c131111111100000e111111110e00
000f1111110f0101001e1111111e1010000d030101010100000e010e10110e0001010f0101010e000011111111191600001111110a0a04000020252525251a0000110a04040a11000000090909060403000f080402010f00030101010101030001010202040408080302020202020300040a110000000000000000000000003f
00010202000000000e1111111f1111000f11110f11110f000e11010101110e001f22222222221e001f01010f01011f001f01010f010101001e01011911111e001111111f1111110007020202020207000f0404040404030011090507090911000101010101010f002121332d2121210011131519111111000e11111111110e00
0f11110f010101000e111111150916000f11110f091111000e11010e10110e001f040404040404001111111111110e00111111110a0a0400414149494955220011110a040a1111001111110a040404001f10080402011f00040a020101020a040101010101010101020504080804050200000026190000000000000000000000
00007f7f7f7f7f000000552a552a55000000417f5d5d3e0000003e6363773e0000001144114411000000021e0e0f080000000e171f1f0e0000001b1f1f0e040000001c3677361c0000000e0e1f0e0a0000001c3e7f2a3a0000003e6763673e0000007f5d7f417f0000001c040407070000003e636b633e000000040e1f0e0400
000000005500000000003e7363733e000000081c7f3e220000001f0e040e1f0000003e7763633e000000000552200000000000112a44000000003e6b776b3e0000007f007f007f000000555555555500000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
04050700000100000000000000607700672000617700060600000000006677070100000060072700000010200070700000000110600020111000102100000671333313111333121333103333117766007600f1758f17677f7788767086182273ff8fff01ffffedff81ff8f7f8188f800ff8fff01ffffeeff88888808818888f0
0007070707070000000007070700000000000705070000000000050205000000000005000500000000000505050000000004060706040000000103070301000000070101010000000000040404070000000507020702000000000001000000000000000001020000000000000303000000050500000000000002050200000000
000000000000000000010101000100000005050000000000000a1f0a1f0a0000000207030607020000050402010500000002050e050e0000000101000000000000020101010200000001020202010000000502070205000000000207020000000000000000010100000000070000000000000000000100000004040201010000
0002050505020000000203020207000000030402010700000003040204030000000505070404000000070103040300000006010305020000000704040202000000020502050200000002050604030000000001000100000000000001000101000000020102000000000003000300000000000102010000000003040200020000
0006090d0106000000000306050700000001030505030000000006010106000000040605050600000000020503060000000402070202000000000605060403000001010305050000000100010101000000020002020201000001050305050000000101010102000000000f151515000000000305050500000000020505020000
000003050503010000000605050604000000030501010000000006030603000000020702020600000000090909060000000005050503000000001111150a000000000502050500000000050505060300000007060307000000030101010300000001020202040000000302020203000000020500000000000000000000070000
0002040000000000000205070505000000030503050300000006010101060000000709090907000000070103010700000007010301010000000e010d090600000005050705050000000101010101000000040404040502000005050305050000000101010107000000111b151111000000090b0f0d0900000006090909060000
0003050301010000000609090d06080000030503050500000006010204030000000702020202000000090909090600000009090905030000001111151b1100000005050205050000000505020202000000070402010700000006020102060000000101000101000000030204020300000000000a050000000003030000000000
007f7f7f7f7f7f0000752a752a752a0000617f5d5d3e0000003e6363773e0000001164116411640000021e0e0f080000000e171f1f0e0000001b1f1f0e040000001c3677361c0000000e0e1f0e0a0000001c3e7f2a3a0000003e6763673e0000003f2d3f213f0000001c040407070000003e636b633e000000040e1f0e040000
0000007500000000003e7363733e000000081c7f3e220000001f0e040e1f0000003e7763633e000000000572200000000000112a64000000003e6b776b3e0000001f001f001f00000015151515150000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100010101000000040e050e0400000c0207020f000000110e0a0e11000000050502070200000001010001010000000603050603000000050000000000000006090d09060000000306050700000000001209120000000000000704000000000000000000000000030503050000000007000000000000
000205020000000000020702000700000003020103000000000103020100000000020100000000000000000505030100000f0b0b0a0a000000000001000000000000000000020300000203020200000000020502000000000000091209000000001109052a3920000011091d120918000021130a757240000000020002010600
000204030605070000020103060507000002050306050700000a0503060507000005000306050700000200030605070000000b160d1f00000000000e010e040000020402050306000002010205030600000205020503060000050002050306000001020000020200000201000001010000020500000202000005000000020200
000e1217120e0000000a050007090900000102000205020000040200020502000002050002050200000a0500060906000005000002050200000005020500000000100e15120d0000000204000909060000040200090906000006090009090600000900000909060000040200050506030001050b0b0501000006090509050000
000204020507050000020102050705000002050205070500000a0506090f090000050002050705000002000205070500001e050f051d0000000e0101010e040000020407030107000002010703010700000205070301070000050007030107000001020002020200000201000101010000020500020202000005000002020200
0002050e09090600000a05090b0d0900000204060909060000040206090906000002050609090600000a0506090906000009000609090600000200070002000000160915120d00000002040909090600000402090909060000020508090906000009000909090600000402050502020000010709090701000005000505020200
